@@ -127,7 +127,7 @@ def _exist_extra_logs(scenario):
 def get_path_extra_logs(scenario):
     extra_logs_folder = os.path.join(
         get_env('logs'),
-        str(get_string_hash(scenario.get('name'))),
+        str(get_string_hash("{}-{}".format(str(scenario["feature"]), str(scenario["name"])))),
         'evidence',
     )
     return extra_logs_folder
@@ -139,7 +139,7 @@ def get_relative_extra_logs_path(scenario):
             [
                 'outputs',
                 'logs',
-                get_string_hash(scenario.get('name')),
+                get_string_hash("{}-{}".format(str(scenario["feature"]), str(scenario["name"]))),
                 'evidence',
             ]
         )
